MethodChannelTelpoM8 class

An implementation of TelpoM8Platform that uses method channels.

Inheritance

Constructors

MethodChannelTelpoM8()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

displayImageOnLCD(Uint8List imageBytes) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printImageWithThermalPrinter(Uint8List imageBytes, int greyScale) Future<void>
override
printWithThermalPrinter(String text, int greyScale) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited